@@ -334,7 +334,7 @@ get_changed_events (ECalBackendExchange *cbex)
 	E2kRestriction *rn;
 	E2kResultIter *iter;
 	E2kResult *result;
-	const gchar *prop, *uid, *modtime, *attach_prop, *receipts, *rid;
+	const gchar *uid, *modtime, *attach_prop, *receipts, *rid;
 	guint status;
 	E2kContext *ctx;
 	gint i, status_tracking = EX_NO_RECEIPTS;
@@ -427,8 +427,11 @@ get_changed_events (ECalBackendExchange *cbex)
 	status = e2k_result_iter_free (iter);
 
 	if (!SOUP_STATUS_IS_SUCCESSFUL (status)) {
-		if (!since)
+		if (!since) {
+			e_cal_backend_exchange_cache_lock (cbex);
 			e_cal_backend_exchange_cache_sync_end (cbex);
+			e_cal_backend_exchange_cache_unlock (cbex);
+		}
 
 		g_ptr_array_free (hrefs, TRUE);
 		g_hash_table_destroy (modtimes);
@@ -437,10 +440,11 @@ get_changed_events (ECalBackendExchange *cbex)
 		return status;
 	}
 
-	e_cal_backend_exchange_cache_lock (cbex);
-	if (!since)
+	if (!since) {
+		e_cal_backend_exchange_cache_lock (cbex);
 		e_cal_backend_exchange_cache_sync_end (cbex);
-	e_cal_backend_exchange_cache_unlock (cbex);
+		e_cal_backend_exchange_cache_unlock (cbex);
+	}
 
 	if (!hrefs->len) {
 		g_ptr_array_free (hrefs, TRUE);
@@ -454,7 +458,6 @@ get_changed_events (ECalBackendExchange *cbex)
 	/* Now get the full text of any that weren't already cached. */
 	/* OWA usually sends the attachment and whole event body as part of
 		PR_INTERNET_CONTENT property. Fetch events created from OWA */
-	prop = PR_INTERNET_CONTENT;
 	iter = e_folder_exchange_bpropfind_start (cbex->folder, NULL,
 						  (const gchar **)hrefs->pdata,
 						  hrefs->len,
@@ -593,10 +596,10 @@ open_calendar (ECalBackendSync *backend, EDataCal *cal,
 	e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
 			E2K_CONTEXT_OBJECT_CHANGED, 30,
 			notify_changes, backend);
-        e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
+	e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
 			E2K_CONTEXT_OBJECT_ADDED, 30,
 			notify_changes, backend);
-        e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
+	e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
 			E2K_CONTEXT_OBJECT_REMOVED, 30,
 			notify_changes, backend);
 
@@ -811,7 +814,7 @@ create_object (ECalBackendSync *backend, EDataCal *cal,
 	#endif
 
 	/* Delegated calendar */
-	if (g_ascii_strcasecmp(e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
+	if (g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
 		process_delegated_cal_object (icalcomp, e_cal_backend_exchange_get_owner_name (backend), e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account));
 
 	/* Send options */
@@ -895,7 +898,7 @@ create_object (ECalBackendSync *backend, EDataCal *cal,
 	body_crlf = icalcomponent_as_ical_string_r (cbdata->vcal_comp);
 
 	date = e_cal_backend_exchange_make_timestamp_rfc822 (time (NULL));
-	if (!g_ascii_strcasecmp(e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
+	if (!g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
 		from = e_cal_backend_exchange_get_from_string (backend, comp);
 	else
 		from = e_cal_backend_exchange_get_sender_string (backend, comp);
@@ -940,7 +943,7 @@ create_object (ECalBackendSync *backend, EDataCal *cal,
 
 	http_status = e_folder_exchange_put_new (E_CAL_BACKEND_EXCHANGE (cbexc)->folder, NULL, summary,
 						NULL, NULL, "message/rfc822",
-						msg, strlen(msg), &location, &ru_header);
+						msg, strlen (msg), &location, &ru_header);
 
 	if ((http_status == E2K_HTTP_CREATED) && send_options) {
 		e2kctx = exchange_account_get_context (E_CAL_BACKEND_EXCHANGE (cbexc)->account);
@@ -1099,7 +1102,7 @@ modify_object (ECalBackendSync *backend, EDataCal *cal,
 
 #define e_return_data_cal_error_and_val_if_fail(expr, _code, _val)		\
 	G_STMT_START {								\
-		if (G_LIKELY(expr)) {						\
+		if (G_LIKELY (expr)) {						\
 		} else {							\
 			g_log (G_LOG_DOMAIN,					\
 				G_LOG_LEVEL_CRITICAL,				\
@@ -1151,9 +1154,9 @@ modify_object_with_href (ECalBackendSync *backend, EDataCal *cal,
 	e_return_data_cal_error_and_val_if_fail (calobj != NULL, InvalidArg, FALSE);
 
 	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
-                g_propagate_error (error, EDC_ERROR (RepositoryOffline));
+		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return FALSE;
-        }
+	}
 
 	if (rid_to_remove)
 		remove = TRUE;
@@ -1261,7 +1264,7 @@ modify_object_with_href (ECalBackendSync *backend, EDataCal *cal,
 	}
 
 	/* Delegated calendar */
-	if (g_ascii_strcasecmp(e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
+	if (g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
 		process_delegated_cal_object (updated_icalcomp, e_cal_backend_exchange_get_owner_name (backend), e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account));
 
 	/* send options */
@@ -1391,8 +1394,12 @@ modify_object_with_href (ECalBackendSync *backend, EDataCal *cal,
 	   the server, so that we don't lose any detached instances */
 	if (ecomp->icomp && mod == CALOBJ_MOD_THIS && remove) {
 		icalcomponent_add_component (cbdata->vcal_comp, icalcomponent_new_clone (ecomp->icomp));
-	} else if (!remove && mod == CALOBJ_MOD_THIS)
+	}
+
+	if (!remove && mod == CALOBJ_MOD_THIS) {
+		icalcomponent_add_component (cbdata->vcal_comp, icalcomponent_new_clone (ecomp->icomp));
 		icalcomponent_add_component (cbdata->vcal_comp, real_icalcomp);
+	}
 
 	for (l = ecomp->instances; l != NULL; l = l->next) {
 		icalcomponent *icomp = l->data;
@@ -1432,7 +1439,7 @@ modify_object_with_href (ECalBackendSync *backend, EDataCal *cal,
 	body_crlf = icalcomponent_as_ical_string_r (cbdata->vcal_comp);
 
 	date = e_cal_backend_exchange_make_timestamp_rfc822 (time (NULL));
-	if (!g_ascii_strcasecmp(e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
+	if (!g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (cbex->account)))
 		from = e_cal_backend_exchange_get_from_string (backend, updated_ecomp);
 	else
 		from = e_cal_backend_exchange_get_sender_string (backend, updated_ecomp);
@@ -1550,8 +1557,8 @@ remove_object (ECalBackendSync *backend, EDataCal *cal,
 
 	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
-                return;
-        }
+		return;
+	}
 
 	e_cal_backend_exchange_cache_lock (cbex);
 	ecomp = get_exchange_comp (E_CAL_BACKEND_EXCHANGE (cbexc), uid);
@@ -1637,8 +1644,8 @@ receive_objects (ECalBackendSync *backend, EDataCal *cal,
 
 	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
-                return;
-        }
+		return;
+	}
 
 	if (!e_cal_backend_exchange_extract_components (calobj, &method, &comps, error))
 		return;
@@ -1720,7 +1727,7 @@ receive_objects (ECalBackendSync *backend, EDataCal *cal,
 					if (e_cal_util_component_is_instance (subcomp))
 						mod = CALOBJ_MOD_THIS;
 
-					icalobj = (gchar *) icalcomponent_as_ical_string_r (subcomp);
+					icalobj = e_cal_component_get_as_string (comp);
 					if (!modify_object_with_href (backend, cal, icalobj,
 									  mod,
 									  &old_object, &new_object, NULL, NULL, error)) {
@@ -1747,7 +1754,7 @@ receive_objects (ECalBackendSync *backend, EDataCal *cal,
 				}
 
 				d(printf ("object : %s .. not found in the cache\n", uid));
-				icalobj = (gchar *) icalcomponent_as_ical_string_r (subcomp);
+				icalobj = e_cal_component_get_as_string (comp);
 				d(printf ("Create a new object : %s\n", icalobj));
 
 				e_cal_backend_exchange_cache_unlock (cbex);
@@ -1920,7 +1927,7 @@ book_resource (ECalBackendExchange *cbex,
 	e_cal_component_get_uid (E_CAL_COMPONENT (comp), &uid);
 	sanitized_uid = g_strdup (uid);
 	g_strdelimit (sanitized_uid, " /'\"`&();|<>$%{}!\\:*?#@", '_');
-	href = g_strdup_printf ("%s%s%s.EML", cal_uri [strlen (cal_uri) - 1] == '/' ? "" : "/", cal_uri, sanitized_uid);
+	href = g_strdup_printf ("%s%s%s.EML", cal_uri, cal_uri [strlen (cal_uri) - 1] == '/' ? "" : "/", sanitized_uid);
 	g_free (sanitized_uid);
 
 	e_cal_backend_exchange_cache_lock (cbex);
@@ -2263,8 +2270,8 @@ discard_alarm (ECalBackendSync *backend, EDataCal *cal,
 
 	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
-                return;
-        }
+		return;
+	}
 
 	cbex = E_CAL_BACKEND_EXCHANGE (backend);
 
@@ -2312,8 +2319,8 @@ get_free_busy (ECalBackendSync *backend, EDataCal *cal,
 
 	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
 		g_propagate_error (perror, EDC_ERROR (RepositoryOffline));
-                return;
-        }
+		return;
+	}
 
 	/* The calendar component sets start to "exactly 24 hours
 	 * ago". But since we're going to get the information in
